@@ -1,3 +1,5 @@
+
+
 package com.openexchange.custom.parallels.soap.dataobjects;
 
 
@@ -8,19 +10,19 @@ package com.openexchange.custom.parallels.soap.dataobjects;
  *
  */
 public class Bundle {
-    
-    private String name;
-    
-    private String status;
 
-    
-    
+    private final String name;
+
+    private final String status;
+
+
+
     /**
      * Initializes a new {@link Bundle}.
      * @param name the name of the bundle
      * @param status the state of the bundle
      */
-    public Bundle(String name, String status) {
+    public Bundle(final String name, final String status) {
         super();
         this.name = name;
         this.status = status;
@@ -38,7 +40,7 @@ public class Bundle {
     }
 
 
-    
+
     /**
      * Returns the state of the bundle
      * 
